import json

from .HttpUtil import HttpUtil


class CoreATASApi:

    @staticmethod
    def init_result(uri, token, launch, executor):
        headers = "{\"Content-Type\": \"application/json;charset=UTF-8\",\"auth-key\": \"" + token + "\"}"
        url = uri + "/automation/launch/init"
        body = "{\"launchName\":\"" + launch + "\", \"executor\": \"" + executor + "\"}"
        method = "post"
        try:
            res = HttpUtil.http_request(url, method, None, None, json.loads(body), headers=eval(headers))
        except Exception:
            raise
        execution_id = json.loads(res)['data']['executionId']
        return execution_id

    @staticmethod
    def save_result(uri, token, data):
        url = uri + "/automation/launch/execute"
        # item = {"executionId": execution_id}
        # data.update(**item)
        screen_path = data['screen_path']
        attachment_path = data['attachment_path']
        if screen_path is None:
            screen = ('snapshot', (
                '', '',
                'image/png'))
        else:
            screen = ('snapshot', (
                screen_path[screen_path.rindex("/") + 1:], open(screen_path, 'rb'),
                'image/png'))
        if attachment_path is None:
            attachment = ('attachment', (
                '', '',
                'image/png'))
        else:
            attachment = ('attachment', (
                attachment_path[attachment_path.rindex("/") + 1:], open(attachment_path, 'rb'),
                'image/png'))
        files = [screen, attachment]
        try:
            res = HttpUtil.http_multipart_request(url, data, files, auth_key=token)
        except Exception:
            raise
        return res

    @staticmethod
    def run_complete(uri, token, execution_id, case_status):
        headers = "{\"Content-Type\": \"application/json;charset=UTF-8\",\"auth-key\": \"" + token + "\"}"
        url = uri + "/automation/launch/execution/complete"
        body = "{\"executionId\":" + str(execution_id) + ", \"caseStatus\": \"" + case_status + "\"}"
        method = "post"
        try:
            res = HttpUtil.http_request(url, method, None, None, json.loads(body), headers=eval(headers))
        except Exception:
            raise
        return res

    @staticmethod
    def get_run_cases(uri, token, id):
        headers = "{\"Content-Type\": \"application/json;charset=UTF-8\",\"auth-key\": \"" + token + "\"}"
        url = uri + "/automation/plan/cases/info"
        body = "{\"executionId\":\"" + id + "\"}"
        method = "post"
        try:
            res = HttpUtil.http_request(url, method, None, None, json.loads(body), headers=eval(headers))
        except Exception:
            raise
        return res



import json
import requests as requests


class HttpUtil:
    @staticmethod
    def http_post(url, parameters, headers):
        if headers is None:
            headers = {"Content-Type": "application/json"}
        res = requests.post(url, data=parameters, headers=headers, verify=True)
        if res.status_code != 200:
            raise Exception("Request exception")
        result = json.loads(res.text)
        return result

    @staticmethod
    def http_get(url, parameters, headers):
        res = requests.get(url, data=parameters, headers=headers, verify=True)
        if res.status_code != 200:
            raise Exception(u"Request exception")
        result = json.loads(res.text)
        return result

    @staticmethod
    def http_request(url, method, params, data, body, **kwargs):
        response = requests.request(method, url, params=params, data=data, json=body, **kwargs, verify=True)
        if response.status_code != 200:
            raise Exception(u"Request exception")
        result = response.text
        return result

    @staticmethod
    def http_multipart_request(url, data, files, auth_key):
        headers = {
            'auth-key': auth_key
        }
        response = requests.request("POST", url, headers=headers, data=data, files=files, verify=True)
        result = response.text
        return result



from .CoreATASApi import CoreATASApi


def init(endpoints, token, launch_name, executor):
    return CoreATASApi.init_result(endpoints, token, launch_name, executor)


def upload_result(endpoints, token, execution_id, case_name, step_desc, step_status, case_status, executor, path,
                  screenshot,
                  attachment, start_time, end_time, test_plan_case_id, run_id):
    data = {'caseName': case_name,
            'path': path,
            'stepStatus': step_status,
            'stepDescription': step_desc,
            'caseStatus': case_status,
            'executor': executor,
            'screen_path': screenshot,
            'attachment_path': attachment,
            'executionId': execution_id,
            'startTime': start_time,
            'endTime': end_time,
            'testCaseId': test_plan_case_id,
            'unionKey': run_id}
    CoreATASApi.save_result(endpoints, token, data)


def complete(endpoints, token, execution_id, case_status):
    CoreATASApi.run_complete(endpoints, token, execution_id, case_status)


def get_run_case(endpoints, token, id):
    CoreATASApi.get_run_cases(endpoints, token, id)
